<?php
//
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 Clever Age                                        |
// +----------------------------------------------------------------------+
// | Author: Antoine Angnieux <aangenieux@clever-age.com>                |
// +----------------------------------------------------------------------+
//
// Base class for NewsletterInstance List Data abstraction.
// $Id$

/**
 * BD_newsletterInstanceListData is a base class for newsletter instances lists data
 *  database abstraction implementations, and must be inherited by all such.
 * @package	BD
 * @author  Antoine Angnieux <aangenieux@clever-age.com>
 * @author 	Erwan Le Bescond <elebescond@clever-age.com>
 * @access	public
 */

require_once ("PEAR.php");
require_once ("DB.php");
require_once (dirname(__FILE__)."/objectlistdata.php");
require_once (dirname(__FILE__)."/inc_listdata_querytypes_constants.php");
require_once (dirname(__FILE__).'/inc_newsletter_instance_factory.php');

class BD_newsletterInstanceListData extends BD_objectListData {

    /**
     * Create a new newsletter instance list data object for the specified database parameters
     * passed
     *
     * @param BD_parameters $dbParameters database configuration object
     * @return mixed a newly created ArticleListData object, or a PEAR error code on
     *               error
     * @access public
     */
    function &factory($dbParameters = null, $dbOptions = null) {
        if(file_exists(dirname(__FILE__)."/".$dbParameters->_dbEngine."/newsletter_instancelistdata_".$dbParameters->_dbEngine.".php") == false) {
            include_once(dirname(__FILE__)."/common/newsletter_instancelistdata_common.php");
            $classname = "BD_newsletterInstanceListData_common";
        }
        else {
            include_once(dirname(__FILE__)."/".$dbParameters->_dbEngine."/newsletter_instancelistdata_".$dbParameters->_dbEngine.".php");
            $classname = "BD_newsletterInstanceListData_".$dbParameters->_dbEngine;
        }

        if (!class_exists($classname)) {
            return PEAR::raiseError("Cannot instanciate class $classname", null,
                                    null, null, null, null, false);
        }

        $obj =& new $classname;

        $result = $obj->setDbParameters($dbParameters);
        if ($dbOptions != null) {
            $obj->setDbOptions($dbOptions);
        }
        if (PEAR::isError($result)) {
            return $result;
        } else {
            return $obj;
        }
    }

    // {{{ constructor

    /**
     * Abstract Constructor.
     *
     * @access public
     */


    function BD_newsletterInstanceListData() {
        $par = get_parent_class(get_parent_class($this));

        $this->$par();
    }

    // }}}


   // {{{ displayHTMLList($titre_table, $queryType, $params, $afficher_visites = false, $afficher_auteurs = true, $toujours_afficher = false, $afficher_cadre = true)

    /**
     * returns the HTML List for the various article data lists implementations
     * This method should <b>NEVER<b> be overloaded, otherwise EXTRA-EXTRA-CARE is required
     * while overloading this method.
     *
     * @return String reprensenting the generated HTML list navigation
     * @param $queryType int representing the desired query type (refer to inc_listdata_query_types_contants.php)
     * @param $params array containing the query parameters
     * @param $countQuery boolean : if set to true, the returned query is a count result query for the specified query type.
     * @access public
     */

    function displayHTMLList($titre_table, $queryType, $params = array()) {
        global $connect_id_auteur, $connect_statut;
        $copyParams = $params;
        $requete = $this->_getQuery($queryType, false, $params);
		$tranches = $this->_getHTMLNavigation($queryType, $copyParams, 3);
        /*
        $tranches = afficher_tranches_requete($requete, $afficher_auteurs ? 3 : 2);
        */
        if (strlen($tranches)) {
        	$db = &$this->_getDB();
            if (DB::isError($db)) {
                die("Impossible d'obternir une connexion  la base de donnes! ".$db->getMessage());
            }
            if ($this->_getQueryIsLimited()) {
                $limitStart = $this->_getLimitStart();
                $limitCount = $this->_getLimitCount();
                $result = $db->limitQuery($requete, $limitStart, $limitCount, $copyParams);
            } else {
                $result = $db->query($requete, $params);
            }
            if (DB::isError($result)) {
                die("la requete a choue! ".$result->getMessage());
            }

            if ($result->numRows() > 0) {
                debut_cadre_relief("newsletter-24.gif");
                echo "<table width='100%' cellpadding='0' cellspacing='0' border='0'><tr><td width='100%' background=''>";
                echo "<table width='100%' cellpadding='3' cellspacing='0' border='0'>";

                bandeau_titre_boite($titre_table, true);
                while ($row = $result->fetchRow()) {
                    echo '<tr bgcolor="#FFFFFF"><td class="arial2" colspan="5"><a href="postinfo.php3?id_post='.$row['pst_id'].'&id_newsletter='.$row['lst_id'].'" title="'.$row['pst_subject'].'"><img src="img_pack/puce-verte.gif" alt="" width="13" height="14" border="0"></a>&nbsp;&nbsp;<a href="postinfo.php3?id_post='.$row['pst_id'].'&id_newsletter='.$row['lst_id'].'" title="'.$row['pst_subject'].'">'.$row['pst_subject'].'</a></td>'
                        .'<td class="arial2" nowrap>cr&eacute;e le '.$row['pst_date_create'].'</td></tr>';
                }
                echo "</table></td></tr></table>";
							 fin_cadre_relief();
            }
            $result->free();

        }
    }
    // }}}

 // {{{ displayHTMLList($titre_table, $queryType, $params, $afficher_visites = false, $afficher_auteurs = true, $toujours_afficher = false, $afficher_cadre = true)

    /**
     * returns the HTML List for the various article data lists implementations
     * This method should <b>NEVER<b> be overloaded, otherwise EXTRA-EXTRA-CARE is required
     * while overloading this method. 
		 * One thing has been added to this function to permit some action via button
     *
     * @return String reprensenting the generated HTML list navigation
     * @param $queryType int representing the desired query type (refer to inc_listdata_query_types_contants.php)
     * @param $params array containing the query parameters
     * @param $countQuery boolean : if set to true, the returned query is a count result query for the specified query type.
     * @access public
     */

    function displayHTMLListWithPercentage($titre_table, $queryType, $params = array(), $preparation = true) {

        global $connect_id_auteur, $connect_statut;
        $copyParams = $params;
        $requete = $this->_getQuery($queryType, false, $params);
				$tranches = $this->_getHTMLNavigation($queryType, $copyParams, 3);
        /*
        $tranches = afficher_tranches_requete($requete, $afficher_auteurs ? 3 : 2);
        */
        
        if (strlen($tranches)) {
        	$db = &$this->_getDB();
            if (DB::isError($db)) {
                die("Impossible d'obternir une connexion  la base de donnes! ".$db->getMessage());
            }
            if ($this->_getQueryIsLimited()) {
                $limitStart = $this->_getLimitStart();
                $limitCount = $this->_getLimitCount();
                // hack Olivier Mansour - limitQuery renvoi une vielle erreur => pas de listes paginees
                // TODO : FIXME
                //$result = $db->limitQuery($requete, $limitStart, $limitCount, $copyParams);
                $result = $db->query($requete, $params);
            } else {
                $result = $db->query($requete, $params);
            }
            if (DB::isError($result)) {
                die("la requete a choue! ".$result->getMessage());
            }

            if ($result->numRows() > 0) {
                debut_cadre_relief("newsletter-24.gif");
                echo "<table width='100%' cellpadding='0' cellspacing='0' border='0'><tr><td width='100%' background=''>";
                echo "<table width='100%' cellpadding='3' cellspacing='0' border='0'>";

                bandeau_titre_boite_articles($titre_table, true);
                while ($row = $result->fetchRow()) {
										$newsletterPartie = &recuperer_instance_newsletter_instance();
										$tabPercentage = $newsletterPartie->percentage_left($row['pst_id'],$row['lst_id']);
										//On vrifie que le dnominateur n'est pas gal  0
										if($tabPercentage[1]!=0)
											$currentPercentage =  round(100*$tabPercentage[0]/$tabPercentage[1],1);
										else
											$currentPercentage = 0;													
                    if(($currentPercentage!=100)&&($preparation == false)){
  										echo '<tr bgcolor="#FFFFFF"><td class="arial2"><a href="postinfo.php3?id_post='.$row['pst_id'].'&id_newsletter='.$row['lst_id'].'" title="'.$row['pst_subject'].'"><img src="img_pack/puce-verte.gif" alt="" width="13" height="14" border="0"></a>&nbsp;&nbsp;<a href="postinfo.php3?id_post='.$row['pst_id'].'&id_newsletter='.$row['lst_id'].'" title="'.$row['pst_subject'].'">'.$row['pst_subject'].'</a></td>'
                          .'<td class="arial2" nowrap>'.$currentPercentage.'%</td><td class="arial2" nowrap>cr&eacute;e le '.$row['pst_date_create'].'</td></tr>';
										}else{
  										if($preparation == true){
													 $formulaireSuppress = "<a href=\"suppress_pst.php3?id_newsletter=".$row['lst_id']."&action=suppress&id_pst=".$row['pst_id']."\" title='"._T('suppressPst')."'  ><img src='img_pack/suppress.gif' height='12' width='12' alt='"._T('suppressPst')."'></a>";
											}else{																				 
											     $formulaireSuppress = "<a href=\"suppress_pst.php3?id_newsletter=".$row['lst_id']."&action=suppress&id_pst=".$row['pst_id']."\" title='"._T('suppressPst')."' ><img src='img_pack/suppress.gif' height='12' width='12' alt='"._T('suppressPst')."'></a>";
  												 $formulaireNbUser = "<a href=\"consult_post_done.php3?id_newsletter=".$row['lst_id']."&action=suppress&id_pst=".$row['pst_id']."\" title='"._T('exporter_la_liste_post')."' ><img src='img_pack/telechargerUser.png' height='12' width='12' alt='"._T('listeSubSent')."'></a>";			
											}

											$authorization = &recuperer_instance_authorization('supprimerLettreEnvoi', $GLOBALS['connect_id_auteur']);
                      if (!$authorization->isAuthorizedAction()) {
                      	$formulaireSuppress = "";
                      }
											$authorization = &recuperer_instance_authorization('exporterSubscriberPostDone', $GLOBALS['connect_id_auteur']);
                      if (!$authorization->isAuthorizedAction()) {
                      	$formulaireNbUser = "";
                      }

											echo '<tr bgcolor="#FFFFFF" align="center"><td class="arial2"><a href="postinfo.php3?id_post='.$row['pst_id'].'&id_newsletter='.$row['lst_id'].'" title="'.$row['pst_subject'].'"><img src="img_pack/puce-verte.gif" alt="" width="13" height="14" border="0"></a>&nbsp;&nbsp;<a href="postinfo.php3?id_post='.$row['pst_id'].'&id_newsletter='.$row['lst_id'].'" title="'.$row['pst_subject'].'">'.$row['pst_subject'].'</a></td>'
                        .'<td class="arial2"  nowrap>'.$formulaireSuppress."&nbsp;&nbsp;".$formulaireNbUser.'</td><td class="arial2" nowrap>cr&eacute;e le '.$row['pst_date_create'].'</td></tr>';
										}
								}
                echo "</table></td></tr></table>";
                fin_cadre_relief();
            }
            $result->free();

        }
    }
    // }}}
		
		
    // {{{ _fillQueries()

    /**
     * This methods fill the query associative arrays with SQL 92 compliant
     * queries. Each driver that requires specific SQL querying must implement
     * the _adaptQueriesToDriver() method.
     * @access  private
     * @see     _adaptQueriesToDriver()
     */
    function _fillQueries() {
        $this->_queries[NEWSLETTER_INSTANCE_BY_SENT_DATE] =
                    'SELECT pst_id, lst_id, pst_date_create, pst_date_update, pst_date_sent, pst_subject '
                   .' FROM '.$GLOBALS['table_prefix'].'_cm_posts'
                   .' WHERE pst_date_sent ! 0 AND lst_id = ?'
                   .' ORDER BY pst_date_sent desc, pst_date_create desc';
       $this->_queriesCount[NEWSLETTER_INSTANCE_BY_SENT_DATE] =
                    'SELECT COUNT(pst_id) '
                   .' FROM '.$GLOBALS['table_prefix'].'_cm_posts'
                   .' WHERE pst_date_sent ! 0 AND lst_id = ?';
    }
    // }}}
    
    
    
     // {{{ _adaptQueriesToDriver()

    /**
     * This method must be redefines in derived class if the driver requires
     * the use of database specific querying (non SQL 92 compliant queries)
     * this method is "protected"
     * @access private
     */
    function _adaptQueriesToDriver() {
        
        
    }

    // }}}

}
?>